RuntimePipeline

Struct RuntimePipeline 

pub struct RuntimePipeline<'a> { /* private fields */ }
Pipeline that processes incoming and locally-generated protocol messages.

Implementations

Source

impl<'a> RuntimePipeline<'a>

pub fn new(store: &'a Store) -> Self

Creates a new pipeline backed by the given store.

pub fn queue_outgoing<T>(&self, envelope: &Envelope<T>) -> Result<()>
where T: Serialize,

Queues a signed envelope for outbound delivery.

pub fn queue_raw_wire(&self, wire: &WireEnvelope) -> Result<()>

Queues a pre-signed wire envelope for outbound delivery.

pub fn ingest_verified<T>(&self, envelope: &Envelope<T>) -> Result<bool>
where T: Serialize,

Saves an incoming envelope to the inbox and returns false if already processed.

pub fn mark_inbox_message_processed(&self, msg_id: &MessageId) -> Result<()>

Marks an inbox message as processed so it is not ingested again.

pub fn ingest_project_charter( &self, envelope: &Envelope<ProjectCharter>, ) -> Result<()>

pub fn ingest_approval_applied( &self, envelope: &Envelope<ApprovalApplied>, ) -> Result<()>

pub fn ingest_task_delegated( &self, envelope: &Envelope<TaskDelegated>, ) -> Result<()>

pub fn ingest_task_result_submitted( &self, envelope: &Envelope<TaskResultSubmitted>, ) -> Result<()>

pub fn ingest_task_progress( &self, envelope: &Envelope<TaskProgress>, ) -> Result<()>

pub fn ingest_stop_order(&self, envelope: &Envelope<StopOrder>) -> Result<()>

pub fn ingest_stop_ack(&self, envelope: &Envelope<StopAck>) -> Result<()>

pub fn ingest_stop_complete( &self, envelope: &Envelope<StopComplete>, ) -> Result<()>

pub fn ingest_snapshot_response( &self, envelope: &Envelope<SnapshotResponse>, ) -> Result<()>

pub fn ingest_evaluation_issued( &self, envelope: &Envelope<EvaluationIssued>, ) -> Result<()>

pub fn ingest_publish_intent_proposed( &self, envelope: &Envelope<PublishIntentProposed>, ) -> Result<()>

pub fn ingest_publish_intent_skipped( &self, envelope: &Envelope<PublishIntentSkipped>, ) -> Result<()>

pub fn ingest_publish_result_recorded( &self, envelope: &Envelope<PublishResultRecorded>, ) -> Result<()>

pub fn record_local_project_charter( &self, envelope: &Envelope<ProjectCharter>, ) -> Result<()>

pub fn record_local_approval_applied( &self, envelope: &Envelope<ApprovalApplied>, ) -> Result<()>

pub fn record_local_task_delegated( &self, envelope: &Envelope<TaskDelegated>, ) -> Result<()>

pub fn record_local_task_result_submitted( &self, envelope: &Envelope<TaskResultSubmitted>, ) -> Result<()>

pub fn record_local_task_progress( &self, envelope: &Envelope<TaskProgress>, ) -> Result<()>

pub fn record_local_publish_intent_proposed( &self, envelope: &Envelope<PublishIntentProposed>, ) -> Result<()>

pub fn record_local_publish_intent_skipped( &self, envelope: &Envelope<PublishIntentSkipped>, ) -> Result<()>

pub fn record_local_publish_result_recorded( &self, envelope: &Envelope<PublishResultRecorded>, ) -> Result<()>

pub fn record_local_stop_order( &self, envelope: &Envelope<StopOrder>, ) -> Result<()>

pub fn record_local_stop_complete( &self, envelope: &Envelope<StopComplete>, ) -> Result<()>